@@ -22,10 +22,24 @@
 ;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 ;; Boston, MA 02111-1307, USA.
 
-(if (not (charsetp 'mule-unicode-0100-24ff))
-    (define-charset 244 'mule-unicode-0100-24ff
-      [2 96 1 0 ?1 0 "Unicode subset" "Unicode subset (U+0100..U+24FF)"
-	 "Unicode characters of the range U+0100..U+24FF."]))
+(defconst mule-unicode-0100-24ff-range
+  '(256 . 9471)
+  "The range of mule-unicode-0100-24ff.
+i.e. '(#x100 . #x24FF).")
+
+;; charset and category definition.
+
+(if (featurep 'xemacs)
+    ;; For XEmacs.
+    nil
+
+  ;;
+  (if (not (charsetp 'mule-unicode-0100-24ff))
+      (define-charset 244 'mule-unicode-0100-24ff
+	[2 96 1 0 ?1 0 "Unicode subset" "Unicode subset (U+0100..U+24FF)"
+	   "Unicode characters of the range U+0100..U+24FF."]))
+  (define-category ?u "Mule unicode characters")
+  (modify-category-entry (make-char 'mule-unicode-0100-24ff) ?u))
 
 (put 'mule-unicode-0100-24ff
      'unicode-assoc
@@ -33,10 +47,10 @@
 
 (defun ucs-to-mule-unicode-0100-24ff (codepoint)
   (if (or (not (numberp codepoint))
-	  (> codepoint ?\x24FF)
-	  (< codepoint ?\x0100))
+	  (> codepoint (cdr mule-unicode-0100-24ff-range))
+	  (< codepoint (car mule-unicode-0100-24ff-range)))
       (error "The given codepoint is invalid:%S" codepoint))
-  (setq codepoint (- codepoint ?\x0100))
+  (setq codepoint (- codepoint (car mule-unicode-0100-24ff-range)))
   (make-char 'mule-unicode-0100-24ff
 	     (+ (/ codepoint 96) 32)
 	     (+ (% codepoint 96) 32)))
@@ -49,29 +63,22 @@
 		       row (nth 1 cs)
 		       col (nth 2 cs)
 		       cs (car cs))))
-	(+ (* (- row 32) 96) (- col 32) ?\x0100)
+	(+ (* (- row 32) 96) (- col 32)
+	   (car mule-unicode-0100-24ff-range))
       (error "The given char is invalid:%S" char))))
 
-(define-category ?u "Mule unicode characters")
-(modify-category-entry (make-char 'mule-unicode-0100-24ff) ?u)
-
-(defvar
-  mule-unicode-0100-24ff-vs-unicode-assoc
-  `(range
-    (char-1 . ucs-generic)
-    (((,(ucs-to-mule-unicode-0100-24ff ?\x0100) .
-       ,(ucs-to-mule-unicode-0100-24ff ?\x24FF)) .
-       (?\x100 . ?\x24FF)))))
-
-;;;
-;;; Font encoder
-;;;
-
-(put 'mule-unicode-0100-24ff
-     'mccl-font-encoder
-     `(list
-       '((r2 += ((r1 * 96) - ,(+ (* 96 32) 32 -256)))
-	 (r1 = (r2 >8 r2))
-	 (r2 = r7))))
+(defvar mule-unicode-0100-24ff-vs-unicode-assoc
+  (if (charsetp 'mule-unicode-0100-24ff)
+      `(range
+	(char-1 . ucs-generic)
+	(((,(ucs-to-mule-unicode-0100-24ff
+	     (car mule-unicode-0100-24ff-range)) .
+	     ,(ucs-to-mule-unicode-0100-24ff
+	       (cdr mule-unicode-0100-24ff-range))) .
+	       ,mule-unicode-0100-24ff-range)))
+    nil))
 
 (provide 'mule-uni)
+
+;;; mule-uni.el ends here.
+
