@@ -84,7 +84,9 @@ by calling post-read-conversion and pre-write-conversion functions.")
 
 (defun un-define-pre-write-conversion (from to)
   (if un-define-enable-buffer-conversion
-      (let ((charsets (find-charset-region from to))
+      (let ((charsets (if (stringp from)
+			  (find-charset-string from)
+			(find-charset-region from to)))
 	    slot func applied)
 	(while charsets
 	  (setq slot (assq (car charsets)
@@ -105,39 +107,49 @@ by calling post-read-conversion and pre-write-conversion functions.")
 ; unicode basic translation charset list.
 ;
   (defvar unicode-basic-translation-charset-order-list
-    '(ascii
-      latin-iso8859-1
-      latin-iso8859-2
-      latin-iso8859-3
-      latin-iso8859-4
-      cyrillic-iso8859-5
-					;      arabic-iso8859-6
-      greek-iso8859-7
-      hebrew-iso8859-8
-      latin-iso8859-9
-      ipa
-      japanese-jisx0208
-      japanese-jisx0212
-      chinese-gb2312
-      chinese-cns11643-1 
-      chinese-cns11643-2
-      chinese-cns11643-3
-      chinese-cns11643-4
-      chinese-cns11643-5
-      chinese-cns11643-6
-      chinese-cns11643-7
-      chinese-big5-1
-      chinese-big5-2
-      korean-ksc5601
-      latin-jisx0201
-      katakana-jisx0201
-      thai-tis620
-      ethiopic
-      indian-is13194
-      chinese-sisheng
-      vietnamese-viscii-lower
-      vietnamese-viscii-upper
-      mule-unicode-0100-24ff)
+    (let ((cand 
+	   '(ascii
+	     latin-iso8859-1
+	     latin-iso8859-2
+	     latin-iso8859-3
+	     latin-iso8859-4
+	     cyrillic-iso8859-5
+					;  arabic-iso8859-6
+	     greek-iso8859-7
+	     hebrew-iso8859-8
+	     latin-iso8859-9
+	     latin-iso8859-14
+	     latin-iso8859-15
+	     ipa
+	     japanese-jisx0208
+	     japanese-jisx0212
+	     chinese-gb2312
+	     chinese-cns11643-1 
+	     chinese-cns11643-2
+	     chinese-cns11643-3
+	     chinese-cns11643-4
+	     chinese-cns11643-5
+	     chinese-cns11643-6
+	     chinese-cns11643-7
+	     chinese-big5-1
+	     chinese-big5-2
+	     korean-ksc5601
+	     latin-jisx0201
+	     katakana-jisx0201
+	     thai-tis620
+	     ethiopic
+	     indian-is13194
+	     chinese-sisheng
+	     vietnamese-viscii-lower
+	     vietnamese-viscii-upper
+	     mule-unicode-0100-24ff))
+	  elem result)
+      (while (setq elem (car cand))
+	(if (or (funcall-if-possible (function find-charset) elem)
+		(funcall-if-possible (function charsetp) elem))
+	    (setq result (cons elem result)))
+	(setq cand (cdr cand)))
+      (nreverse result))
     "*Charset order used by unicode-basic-translation.")
 
   (defvar un-define-safe-charsets-for-coding-systems
