@@ -30,13 +30,29 @@
 
 (require 'un-data)
 
+;;; ucs-generic character elisp representation
+;;   (1) ... a simple number.
+;;   (2) ... a string that shows a number in c-format.
+;;           E.g., "0x611A"
+;; If any other representations are converted to elisp
+;; representation, normalize it to (1) form.
+;; Why introduce (2)?  Because there is no compatible format
+;; on hexadecimal literal between Emacs20 and XEmacs...x_x;
+
+(defun ucs-generic-elisp-representation (x)
+  (if (numberp x)
+      x
+    (if (stringp x)
+	(c-notated-string-to-number x)
+      (error "Invalid ucs-generic represenation:%S" x))))
+
 ;;;
 ;;; UCS generic type definition.
 ;;;
 (mucs-define-type
  'ucs-generic
- 'identity
- 'identity)
+ (function ucs-generic-elisp-representation)
+ (function identity))
 
 ;
 ; Unicode or its transformation format support function.
