@@ -1,6 +1,6 @@
 ;;; unidata.el --- UNIDATA parser and viewer.
 
-;; Copyright (C) 2000 Miyashita Hisashi
+;; Copyright (C) 2000 MIYASHITA Hisashi
 
 ;; Keywords: character set, ISO10646, Unicode
 
@@ -24,6 +24,7 @@
 ;; Comment: This program parses and shows UNIDATA distributed by
 ;;          Unicode Consortium.
 
+(require 'trans-util)
 (require 'txt-tbl)
 (require 'unicode)
 
@@ -136,7 +137,7 @@
     (titlecase-mapping number)))
 
 (defvar unidata-values
-  (make-vector ?\x10000 nil))
+  (make-vector (cn "0x10000") nil))
 
 (defun unidata-set-entry (codepoint val)
   (aset unidata-values codepoint val))
